#
# spec file for package hyfetch
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define skip_python2 1
Name:           hyfetch
Version:        1.99.0
Release:        3.3
Summary:        Customizable Linux System Information Script
License:        MIT
Group:          Productivity/Text/Utilities
URL:            https://github.com/hykilpikonna/HyFetch
Source:         https://files.pythonhosted.org/packages/source/H/HyFetch/HyFetch-%{version}.tar.gz
# PATCH-FIX-SUSE Fix E: env-script-interpreter
Patch0:         fix-shebang.patch
# PATCH-FIX-UPSTREAM
Patch1:         https://patch-diff.githubusercontent.com/raw/hykilpikonna/hyfetch/pull/362.patch
BuildRequires:  %{python_module pip}
BuildRequires:  %{python_module setuptools}
BuildRequires:  %{python_module wheel}
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
Requires(post): update-alternatives
Requires(postun): update-alternatives
Recommends:     maim
Recommends:     w3m-inline-image
BuildArch:      noarch
%python_subpackages

%description
HyFetch is a command line script to display information about your
Linux system, such as amount of installed packages, OS and kernel
version, active GTK theme, CPU info, and used/available memory.
It is a fork of neofetch, and adds pride flag coloration to the OS logo.

%package -n neowofetch
# version as reported by neowofetch --version
Version:        7.98.0
Summary:        CLI system information tool written in BASH
Provides:       neofetch = %{version}
Obsoletes:      neofetch < %{version}

%description -n neowofetch
Displays information about the system next to an image, the OS logo, or any
ASCII file of choice. The main purpose of Neofetch is to be used in
screenshots to show other users what OS/Distro is running, what Theme/Icons
are being used, etc.

Customizable through the use of command line flags or the user config file.
There are over 50 config options to mess around with and there's the `print_info()
function and friends which let you add your own custom info.

This is the forked version that is maintained together with hyfetch

%prep
%autosetup -p1 -n HyFetch-%{VERSION}
# copy the patched neofetch to scripts/ - in git, this is a symlink, but the tarball has it as a regular file
cp neofetch hyfetch/scripts/neowofetch

%build
sed -i 's/packages=find_namespace_packages(exclude=("tools", "tools.*")),/packages=find_namespace_packages(exclude=("tools", "tools.*", "docs")),/' setup.py
%pyproject_wheel

%install
%pyproject_install
%python_clone -a %{buildroot}/%{_bindir}/hyfetch
%python_expand %fdupes %{buildroot}%{$python_sitelib}
ln -s %{_bindir}/neowofetch %{buildroot}%{_bindir}/neofetch

%post
%{python_install_alternative hyfetch}

%postun
%python_uninstall_alternative hyfetch

%check
[ "$(%{buildroot}%{_bindir}/neofetch --version)" == "Neofetch %{version}" ] || (
    echo "Neofetch version does not match the RPM version - please update"
    exit 1
)

%files %{python_files}
%doc README.md
%license LICENSE.md
%python_alternative %{_bindir}/hyfetch
%{python_sitelib}/hyfetch
%{python_sitelib}/HyFetch-%{VERSION}.dist-info

%files -n neowofetch
%{_bindir}/neofetch
%{_bindir}/neowofetch

%changelog
* Fri Nov  8 2024 Dominique Leuenberger <dimstar@opensuse.org>
- Add 362.patch: update openSUSE distro logos in the source code.
* Tue Oct 29 2024 Dominique Leuenberger <dimstar@opensuse.org>
- Split out neowofetch into an own subpackage, called neowofetch
  (replacing the original neofetch package, which is archived).
- Do not clone nfeowofetch and don't use update-alternatives on it:
  it's a bash script without any relevance to python vesions.
- Provide symlink to allow calling neowofetch as neofetch directly.
* Sat Oct 26 2024 Cat Kasin <cat@aulucya.gay>
- Update to version 1.99.0
  * Add plural, genderflux, girlflux, Fraysexual, Xenogender, Caninekin,
  Kenochoric, veldian, solian, lunian, Polyamorous, sapphic, androgyne,
  interprogress, progress, intersex, equal-rights, drag, neofluid, genderqueer,
  pronoun, queer subculture, and Gilbert Backer's origin rainbow flgs
  * Add random flag option
  * Fix distro logo triple-quotation mark escaping
  * Fix termux compatibility
  * Fix term background detection not resetting properly
  * Remove typing-extensions and setuptools dependencies
  * Allow lightness value without a '%%' sign in config prompt
  * Support host info on PowerPC Macs
  * Show Kinfo for Plasma 6
  * List all intel GPU as detected
  * Add eweOS, Fedora Immutable distros, Macaroni OS, Ironclad OS,
  Chimera Linux, Tatra, Furreto Linux, BlackMesa, Magix, Mauna, Arkane Linux,
  Linux From Scratch distro flags
  * Update PikaOS logo
  * Add Fedora unicode logo
  * Fix colors not reverting properly
  * Fix terminal emulator selection
  * Fix terminal font info for yakuake
  * Display neovim version
  * Add an option to hide some package managers
  * Fix npm list count mismatch
  * Add "AM" application manager, pnpm, pkgx.sh, pip, bonsai, rad, radula,
  birb, MacPorts for Linux package managers
  * Use XDG path for Nix package counting
  * Fix short package count
  * Add Cider player
* Sun Dec  3 2023 Bailey Kasin <baileykasin@gmail.com>
- Update to version 1.4.11
  * Add ability to set backend args in config file
  * Fix config file argument (Obsoletes fix-config-flag.patch)
  * Fix DE empty bracket in macOS
  * Disable Hackintosh check on arm64 processors
  * Add Windows NT
  * Fixed Kubuntu recognized as Ubuntu
  * Use /etc/debian_version to get .x on Debian
  * Add LainOS, aerOS, Xenia, EndeavourOS Small Option, AZOS, MainsailOS,
  Interix, Peropesis, Adelie, Xray_OS
  * Update AOSC, phyOS, Parch logos
  * Add linux_small
  * Fix color blocks for bash != 3 & < 5
  * Use sed -r instead of -E when using GNU sed
  * Improved macOS resolution detection
  * Add support for alacritty's new config format
  * Check for newer xfce4-term config
  * Add support for npm global packages
* Thu Sep  7 2023 Bailey Kasin <baileykasin@gmail.com>
- Add version 1.4.10
